kumoai
======

Initialization
--------------

The Kumo SDK must be initialized before it is used with a URL and API key,
along with other configuration parameters.

.. currentmodule:: kumoai

.. autosummary::
   :nosignatures:
   :toctree: ../generated

   init
   set_log_level

Enums
-----

Enumerations listed here can be used to define column data types
(:class:`~kumoai.Dtype`) and semantic types (:class:`~kumoai.Stype`).

.. currentmodule:: kumoai

.. autosummary::
   :nosignatures:
   :toctree: ../generated

   Dtype
   Stype

Experimental Features
---------------------

Experimental classes for the Kumo Relational Foundation Model (RFM).

.. note::
   These features are experimental and the API may change in future releases.

For detailed documentation of the experimental RFM classes, see :doc:`experimental_rfm`.
